Usage in QCxMS
==============

The `QCxMS`_ project for the quantum chemical simulation of mass spectra\ :footcite:`asgeirsson2017`\ :footcite:`koopman2019` uses *tblite* as backend to implement the GFN1-xTB, GFN2-xTB and IPEA1-xTB Hamiltonians.

.. note::

   Support in QCxMS is available with version 5.1.0 and later.
   For more details see the `release notes of version 5.1.0 <https://github.com/qcxms/QCxMS/releases/tag/v.5.1.0>`_.

.. _qcxms: https://github.com/qcxms/qcxms


Literature
----------

.. footbibliography::
